@@ -14,7 +14,6 @@ def rm_hyphen_rf(path):
 		pass
 
 
-
 def hash(x):
 	from zlib import crc32
 	return crc32(bytes(str(x), encoding='utf-8'))
@@ -116,7 +115,7 @@ Install with: `pip install {package_name}`
 		],
 		python_requires='>=3.6',
 		entry_points = {
-			'console_scripts': [ f'{package_name}={package_name}.__init__:main' ],
+			'console_scripts': [ f'{package_name}={package_name}:main' ],
 		} if install else {}
 	)
 
@@ -153,4 +152,20 @@ def save_shelve(dir, globals, filename=DEFAULT_SHELVE_FILENAME, stopwords=DEFAUL
 			# except:
 			except TypeError:
 				if key not in stopwords:
-					print('ERROR shelving: {0}'.format(key))
\ No newline at end of file
+					print('ERROR shelving: {0}'.format(key))
+					
+def suspend_file(path):
+	import os
+	suffix = '.' + get_time_str()
+	path2 = path + suffix
+	
+	if os.exists(path2):
+		suffix2 = cool_hash(path2)
+		while True:
+			path3 = path2 + '.' + suffix2
+			if os.exists(path3):
+				suffix2 = cool_hash(path3)
+			else:
+				path2 = path3
+				break
+	os.rename(path, path2)
\ No newline at end of file
